==> HostCMS.Free_6.7.tar.gz: modules/shop/exchange/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'!download' => '-- Не загружать --',
	'group_id' => 'Идентификатор раздела',
	'group_name' => 'Название раздела',
	'group_path' => 'Путь для раздела',
	'group_sorting' => "Порядок сортировки раздела",
	'group_description' => 'Описание раздела',
	'group_seo_title' => "Заголовок раздела(title)",
	'group_seo_description' => "Описание раздела(description)",
	'group_seo_keywords' => "Ключевые слова раздела(keywords)",
	'group_image_large' => 'Файл изображения для группы товаров',
	'group_image_small' => 'Файл малого изображения для группы товаров',
	'group_guid' => 'CML GROUP ID идентификатор группы товаров',
	'parent_group_guid' => 'CML GROUP ID идентификатор родительской группы товаров',
	'currency_id' => 'Идентификатор валюты',
	'tax_id' => 'Идентификатор налога для товара',
	'producer_id' => 'Идентификатор производителя',
	'producer_name' => 'Название производителя',
	'seller_id' => 'Идентификатор продавца',
	'seller_name' => 'Название продавца',
	'measure_id' => 'Идентификатор единицы измерения',
	'measure_value' => 'Название единицы измерения',
	'item_id' => 'Идентификатор товара',
	'item_name' => 'Название товара',
	'item_datetime' => 'Дата',
	'item_marking' => 'Артикул товара',
	'item_description' => 'Описание товара',
	'item_text' => 'Текст для товара',
	'item_image_large' => 'Файл изображения для товара',
	'item_image_small' => 'Файл малого изображения для товара',
	'item_tags' => 'Метки',
	'item_weight' => 'Вес товара',
	'item_length' => 'Длина',
	'item_width' => 'Ширина',
	'item_height' => 'Высота',
	'item_price' => 'Цена товара',
	'item_active' => 'Активность товара',
	'item_sorting' => 'Порядок сортировки товара',
	'item_path' => 'Путь к товару',
	'item_seo_title' => "Заголовок (title)",
	'item_seo_description' => "Значение мета-тега description для страницы с товаром",
	'item_seo_keywords' => "Значение мета-тега keywords для страницы с товаром",
	'item_indexing' => 'Флаг индексации',
	'item_yandex_market' => 'Флаг "Экспортировать в Яндекс.Маркет"',
	'item_yandex_market_bid' => 'Яндекс.Маркет основная расценка',
	'item_yandex_market_cid' => 'Яндекс.Маркет расценка для карточек моделей',

	'item_yandex_market_manufacturer_warranty' => 'Гарантия производителя',
	'item_yandex_market_vendorcode' => 'Код товара от производителя',
	'item_yandex_market_country_of_origin' => 'Страна производства',

	'item_parent_marking' => 'Артикул родительского товара для модификации',
	'item_parent_guid' => 'CML ID родительского товара для модификации',
	'digital_item_value' => "Текст электронного товара",
	'digital_item_filename' => "Файл электронного товара",
	'digital_item_count' => "Количество электронного товара",
	'item_end_datetime' => 'Дата завершения публикации',
	'item_start_datetime' => 'Дата публикации',
	'item_type' => 'Тип товара',
	'item_additional_group' => "Ярлыки GUID",
	'specialprices_min_quantity' => "Количество товара от",
	'specialprices_max_quantity' => "Количество товара до",
	'specialprices_price' => "Значение цены",
	'specialprices_percent' => "Процент от цены",
	'item_guid' => "CML ID идентификатор товара",
	'group_active' => "Активность группы",
	'item_parent_associated' => "Артикул родительского товара для сопутствующего товара",
	'item_associated_markings' => "Артикулы сопутствующих товаров",
	'siteuser_id' => "Идентификатор пользователя сайта",
	'digital_item_name' => "Название электронного товара",
	'item_yandex_market_sales_notes' => "Sales notes",

	'order_guid' => "GUID заказа",
	'order_number' => "Номер заказа",
	'order_country' => "Страна",
	'order_location' => "Область",
	'order_city' => "Город",
	'order_city_area' => "Район",
	'order_name' => "Имя заказчика",
	'order_surname' => "Фамилия заказчика",
	'order_patronymic' => "Отчество заказчика",
	'order_email' => "E-mail заказчика",
	'order_akt' => "Акт",
	'order_schet_fak' => "Счет-фактура",
	'order_company_name' => "Название компании",
	'order_inn' => "ИНН",
	'order_kpp' => "КПП",
	'order_phone' => "Телефон",
	'order_fax' => "Факс",
	'order_address' => "Адрес",
	'order_order_status' => "Статус заказа",
	'order_currency' => "Валюта заказа",
	'order_payment_system_id' => "Идентификатор платежной системы",
	'order_date' => "Дата заказа",
	'order_pay_status' => "Статус оплаты заказа",
	'order_pay_date' => "Дата оплаты заказа",
	'order_description' => "Описание заказа",
	'order_info' => "Информация о заказе",
	'order_canceled' => "Заказ отменен",
	'order_pay_status_change_date' => "Дата изменения статуса заказа",
	'order_delivery_info' => "Информация о доставке",
	'order_item_marking' => "Артикул товара заказа",
	'order_item_name' => "Название товара заказа",
	'order_item_quantity' => "Количество товара заказа",
	'order_item_price' => "Цена товара заказа",
	'order_item_rate' => "Налог на товар заказа",
	'order_item_type' => "Тип товара"
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/exchange/i18n/ru.php <==
<?php

return array(
	'!download' => '-- Не загружать --',
	'group_id' => 'Идентификатор раздела',
	'group_name' => 'Название раздела',
	'group_path' => 'Путь для раздела',
	'group_sorting' => "Порядок сортировки раздела",
	'group_description' => 'Описание раздела',
	'group_seo_title' => "Заголовок раздела(title)",
	'group_seo_description' => "Описание раздела(description)",
	'group_seo_keywords' => "Ключевые слова раздела(keywords)",
	'group_image_large' => 'Файл изображения для группы товаров',
	'group_image_small' => 'Файл малого изображения для группы товаров',
	'group_guid' => 'CML GROUP ID идентификатор группы товаров',

	'group_seo_group_title_template' => 'Шаблон title группы',
	'group_seo_group_description_template' => 'Шаблон description группы',
	'group_seo_group_keywords_template' => 'Шаблон keywords группы',

	'group_seo_item_title_template' => 'Шаблон title товара',
	'group_seo_item_description_template' => 'Шаблон description товара',
	'group_seo_item_keywords_template' => 'Шаблон keywords товара',

	'parent_group_guid' => 'CML GROUP ID идентификатор родительской группы товаров',
	'currency_id' => 'Идентификатор валюты',
	'tax_id' => 'Идентификатор налога для товара',
	'producer_id' => 'Идентификатор производителя',
	'producer_name' => 'Название производителя',
	'seller_id' => 'Идентификатор продавца',
	'seller_name' => 'Название продавца',
	'measure_id' => 'Идентификатор единицы измерения',
	'measure_value' => 'Название единицы измерения',
	'item_id' => 'Идентификатор товара',
	'item_name' => 'Название товара',
	'item_datetime' => 'Дата',
	'item_marking' => 'Артикул товара',
	'item_description' => 'Описание товара',
	'item_text' => 'Текст для товара',
	'item_image_large' => 'Файл изображения для товара',
	'item_image_small' => 'Файл малого изображения для товара',
	'item_tags' => 'Метки',
	'item_weight' => 'Вес товара',
	'item_length' => 'Длина',
	'item_width' => 'Ширина',
	'item_height' => 'Высота',
	'item_min_quantity' => 'Мин. кол-во',
	'item_max_quantity' => 'Макс. кол-во',
	'item_quantity_step' => 'Шаг',
	'item_yandex_vendorcode' => 'Код товара от производителя',
	'item_price' => 'Цена товара',
	'item_active' => 'Активность товара',
	'item_sorting' => 'Порядок сортировки товара',
	'item_path' => 'Путь к товару',
	'item_full_path' => 'Полный путь к товару',
	'item_seo_title' => "Заголовок (title)",
	'item_seo_description' => "Значение мета-тега description для страницы с товаром",
	'item_seo_keywords' => "Значение мета-тега keywords для страницы с товаром",
	'item_indexing' => 'Флаг индексации',
	'item_yandex_market' => 'Флаг "Экспортировать в Яндекс.Маркет"',
	'item_yandex_market_bid' => 'Яндекс.Маркет основная расценка',
	'item_yandex_market_cid' => 'Яндекс.Маркет расценка для карточек моделей',

	'item_yandex_market_manufacturer_warranty' => 'Гарантия производителя',
	'item_yandex_market_vendorcode' => 'Код товара от производителя',
	'item_yandex_market_country_of_origin' => 'Страна производства',

	'item_parent_marking' => 'Артикул родительского товара для модификации',
	'item_parent_guid' => 'CML ID родительского товара для модификации',
	'digital_item_value' => "Текст электронного товара",
	'digital_item_filename' => "Файл электронного товара",
	'digital_item_count' => "Количество электронного товара",
	'item_end_datetime' => 'Дата завершения публикации',
	'item_start_datetime' => 'Дата публикации',
	'item_type' => 'Тип товара',
	'item_additional_group' => "Ярлыки GUID",
	'item_barcode' => "Штрихкоды",
	'item_sets_guid' => 'Товары в комплекте (CML ID)',
	'item_sets_marking' => 'Товары в комплекте (Артикулы)',
	'specialprices_min_quantity' => "Количество товара от",
	'specialprices_max_quantity' => "Количество товара до",
	'specialprices_price' => "Значение цены",
	'specialprices_percent' => "Процент от цены",
	'item_guid' => "CML ID идентификатор товара",
	'group_active' => "Активность группы",
	'item_parent_associated' => "Артикул родительского товара для сопутствующего товара",
	'item_associated_markings' => "Артикулы сопутствующих товаров",
	'item_tabs' => "Вкладки товара",
	'caption_modifications' => "Модификации товара по свойствам",
	'modification_by_property' => "Модификации по %s",

	'siteuser_id' => "Идентификатор пользователя сайта",
	'digital_item_name' => "Название электронного товара",
	'item_yandex_market_sales_notes' => "Sales notes",

	'order_guid' => "GUID заказа",
	'order_number' => "Номер заказа",
	'order_country' => "Страна",
	'order_location' => "Область",
	'order_city' => "Город",
	'order_city_area' => "Район",
	'order_name' => "Имя заказчика",
	'order_surname' => "Фамилия заказчика",
	'order_patronymic' => "Отчество заказчика",
	'order_email' => "E-mail заказчика",
	'order_akt' => "Акт",
	'order_schet_fak' => "Счет-фактура",
	'order_company_name' => "Название компании",
	'order_inn' => "ИНН",
	'order_kpp' => "КПП",
	'order_phone' => "Телефон",
	'order_fax' => "Факс",
	'order_address' => "Адрес",
	'order_order_status' => "Статус заказа",
	'order_currency' => "Валюта заказа",
	'order_payment_system_id' => "Идентификатор платежной системы",
	'order_date' => "Дата заказа",
	'order_pay_status' => "Статус оплаты заказа",
	'order_pay_date' => "Дата оплаты заказа",
	'order_description' => "Описание заказа",
	'order_info' => "Информация о заказе",
	'order_canceled' => "Заказ отменен",
	'order_pay_status_change_date' => "Дата изменения статуса заказа",
	'order_delivery_info' => "Информация о доставке",
	'order_item_marking' => "Артикул товара заказа",
	'order_item_name' => "Название товара заказа",
	'order_item_quantity' => "Количество товара заказа",
	'order_item_price' => "Цена товара заказа",
	'order_item_rate' => "Налог на товар заказа",
	'order_item_type' => "Тип товара",
	'shop_warehouse_inventory' => "Инвентаризация при импорте товара",
	'shop_price_setting' => "Установка цены при импорте товара",
);
